import {
    ChangeDetectionStrategy,
    Component,
    ElementRef,
    Input,
    OnChanges,
    SimpleChanges,
    ViewChild,
} from '@angular/core';
import { DangerousArtifact } from '../../../../../../../ng-swagger-gen/models/dangerous-artifact';
import * as Highcharts from 'highcharts';

@Component({
    selector: 'app-single-bar',
    templateUrl: './single-bar.component.html',
    styleUrls: ['./single-bar.component.scss'],
    changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SingleBarComponent implements OnChanges {
    @Input()
    dangerousArtifact: DangerousArtifact;

    @ViewChild('container', { static: true })
    container: ElementRef;

    ngOnChanges(changes: SimpleChanges) {
        if (changes && changes['dangerousArtifact']) {
            this.initChart();
        }
    }

    initChart() {
        (Highcharts as any).chart(this.container.nativeElement, {
            credits: {
                enabled: false,
            },
            chart: {
                backgroundColor: 'transparent',
                type: 'bar',
            },
            title: {
                text: '',
            },
            tooltip: {
                pointFormat: '{series.data.name}{point.y}',
                style: {
                    fontSize: 12,
                    whiteSpace: 'nowrap',
                },
            },
            plotOptions: {
                pie: {
                    startAngle: -90,
                    endAngle: 90,
                    dataLabels: {
                        enabled: true,
                        distance: -8,
                        style: {
                            fontSize: 8,
                            fontWeight: 1,
                        },
                        pointFormat: '{point.y}',
                    },
                    size: 50,
                    borderWidth: 0,
                    borderRadius: 2,
                },
            },
            series: [
                {
                    type: 'pie',
                    name: 'Severity',
                    data: [
                        {
                            name: 'Critical',
                            y: this.dangerousArtifact?.critical_cnt || 0,
                            color: 'red',
                        },
                        {
                            name: 'High',
                            y: this.dangerousArtifact?.high_cnt || 0,
                            color: '#e64524',
                        },
                        {
                            name: 'Medium',
                            y: this.dangerousArtifact?.medium_cnt || 0,
                            color: 'orange',
                        },
                    ],
                },
            ],
        });
    }
}
